@@ -65,7 +65,6 @@ struct ECalBackendExchangePrivate {
 	GHashTable *objects, *cache_unseen;
 	gchar *object_cache_file;
 	gchar *lastmod;
-	gchar *local_attachment_store;
 	guint save_timeout_id;
 	GMutex *set_lock;
 	GMutex *open_lock;
@@ -161,17 +160,19 @@ load_cache (ECalBackendExchange *cbex,
             E2kUri *e2kuri,
             GError **perror)
 {
+	ESource *source;
 	icalcomponent *vcalcomp, *comp, *tmp_comp;
 	struct icaltimetype comp_last_mod, folder_last_mod;
 	icalcomponent_kind kind;
 	icalproperty *prop;
-	gchar *lastmod, *mangled_uri, *storage_dir;
+	gchar *lastmod, *mangled_uri, *storage_dir, *local_store;
 	const gchar *user_cache_dir;
 	const gchar *uristr;
 	gint i;
 	struct stat buf;
 
-	uristr = e_cal_backend_get_uri (E_CAL_BACKEND (cbex));
+	source = e_backend_get_source (E_BACKEND (cbex));
+	uristr = e_source_get_uri (source);
 	cbex->priv->object_cache_file =
 		e_folder_exchange_get_storage_file (cbex->folder, "cache.ics");
 	if (!cbex->priv->object_cache_file) {
@@ -197,16 +198,16 @@ load_cache (ECalBackendExchange *cbex,
 	}
 
 	user_cache_dir = e_get_user_cache_dir ();
-	cbex->priv->local_attachment_store = g_build_filename (
-		user_cache_dir, "calendar", mangled_uri, NULL);
+	local_store = g_build_filename (user_cache_dir, "calendar", mangled_uri, NULL);
+	e_cal_backend_set_cache_dir (E_CAL_BACKEND (cbex), local_store);
 	storage_dir = g_path_get_dirname (cbex->priv->object_cache_file);
 
-	if (g_lstat (cbex->priv->local_attachment_store , &buf) < 0) {
+	if (g_lstat (local_store, &buf) < 0) {
 #ifdef G_OS_UNIX
 		gint failed = TRUE;
 
  again:
-		if (symlink (storage_dir, cbex->priv->local_attachment_store) < 0)
+		if (symlink (storage_dir, local_store) < 0)
 			g_warning ("%s: symlink() failed: %s", G_STRFUNC, g_strerror (errno));
 		else
 			failed = FALSE;
@@ -225,15 +226,13 @@ load_cache (ECalBackendExchange *cbex,
 			g_free (parent_dir);
 		}
 #else
-		g_warning ("should symlink %s->%s, huh?",
-			   cbex->priv->local_attachment_store,
-			   storage_dir);
-
-		g_mkdir_with_parents (cbex->priv->local_attachment_store, 0700);
+		g_warning ("should symlink %s->%s, huh?", local_store, storage_dir);
+		g_mkdir_with_parents (local_store, 0700);
 #endif
 	}
 	g_free (storage_dir);
 	g_free (mangled_uri);
+	g_free (local_store);
 
        /* Check if the cache file is present. If it is not present the account might
 	  be newly created one. It will be created while save the cache */
@@ -379,21 +378,23 @@ open_calendar (ECalBackendSync *backend,
 	ExchangeAccountResult acresult;
 	gboolean load_result;
 	E2kUri *euri = NULL;
+	ESource *source;
 
 	d(printf("ecbe_open_calendar(%p, %p, %sonly if exists, user=%s, pass=%s)\n", backend, cal, only_if_exists?"":"not ", username?username:"(null)", password?password:"(null)"));
 
-	uristr = e_cal_backend_get_uri (E_CAL_BACKEND (backend));
+	source = e_backend_get_source (E_BACKEND (backend));
+	uristr = e_source_get_uri (source);
 
 	g_mutex_lock (cbex->priv->open_lock);
 
-	if (!e_cal_backend_is_online (E_CAL_BACKEND (cbex))) {
+	if (!e_backend_get_online (E_BACKEND (cbex))) {
 		ESource *source;
 		const gchar *display_contents = NULL;
 
 		d(printf ("ECBE : cal is offline .. load cache\n"));
 
 		cbex->priv->read_only = TRUE;
-		source = e_cal_backend_get_source (E_CAL_BACKEND (cbex));
+		source = e_backend_get_source (E_BACKEND (cbex));
 		display_contents = e_source_get_property (source, "offline_sync");
 
 		if (!display_contents || !g_str_equal (display_contents, "1")) {
@@ -470,10 +471,12 @@ authenticate_user (ECalBackendSync *backend,
 	E2kHTTPStatus status;
 	E2kResult *results;
 	E2kUri *euri = NULL;
+	ESource *source;
 	gint nresults = 0;
 	guint access = 0;
 
-	uristr = e_cal_backend_get_uri (E_CAL_BACKEND (backend));
+	source = e_backend_get_source (E_BACKEND (backend));
+	uristr = e_source_get_uri (source);
 
 	exchange_account_connect (cbex->account, e_credentials_peek (credentials, E_CREDENTIALS_KEY_PASSWORD), &acresult);
 	if (acresult != EXCHANGE_ACCOUNT_CONNECT_SUCCESS) {
@@ -490,7 +493,7 @@ authenticate_user (ECalBackendSync *backend,
 		 * only_if_exists is FALSE.
 		 */
 
-		source = e_cal_backend_get_source (E_CAL_BACKEND (cbex));
+		source = e_backend_get_source (E_BACKEND (cbex));
 		foreign = e_source_get_property (source, "foreign");
 		favorite = g_strrstr (uristr, ";favorites");
 
@@ -971,7 +974,7 @@ create_object (ECalBackendSync *backend,
                GCancellable *cancellable,
                const gchar *calobj,
                gchar **uid,
-               gchar **new_object,
+               icalcomponent **new_object,
                GError **perror)
 {
 	g_propagate_error (perror, EDC_ERROR (NotSupported));
@@ -984,8 +987,8 @@ modify_object (ECalBackendSync *backend,
                GCancellable *cancellable,
                const gchar *calobj,
                CalObjModType mod,
-               gchar **old_object,
-               gchar **new_object,
+               icalcomponent **old_object,
+               icalcomponent **new_object,
                GError **perror)
 {
 	g_propagate_error (perror, EDC_ERROR (NotSupported));
@@ -1422,27 +1425,25 @@ start_view (ECalBackend *backend,
 }
 
 static void
-set_online (ECalBackend *backend,
-            gboolean is_online)
+notify_online_cb (ECalBackend *backend,
+                  GParamSpec *pspec)
 {
 	ECalBackendExchange *cbex;
 	ECalBackendExchangePrivate *priv;
-	gboolean re_open = FALSE;
+	gboolean online;
 
 	cbex = E_CAL_BACKEND_EXCHANGE (backend);
 	priv = cbex->priv;
 
-	d(printf("ecbe_set_online(%p) : online : %d\n", backend, is_online ? 1 :0));
-
-	re_open = is_online && !e_cal_backend_is_online (backend);
-	e_cal_backend_notify_online (backend, is_online);
+	online = e_backend_get_online (E_BACKEND (backend));
+	e_cal_backend_notify_online (backend, online);
 
 	g_mutex_lock (priv->set_lock);
 
-	if (is_online) {
+	if (online) {
 		priv->read_only = FALSE;
 
-		if (e_cal_backend_is_opened (backend) && re_open)
+		if (e_cal_backend_is_opened (backend))
 			e_cal_backend_notify_auth_required (backend, TRUE, NULL);
 	} else {
 		priv->read_only = TRUE;
@@ -1693,7 +1694,7 @@ get_attachment (ECalBackendExchange *cbex,
 				stream = camel_stream_mem_new_with_byte_array (byte_array);
 				camel_data_wrapper_decode_to_stream_sync (content, stream, NULL, NULL);
 				attach_data = g_memdup (byte_array->data, byte_array->len);
-				attach_file = g_strdup_printf ("%s/%s-%s", cbex->priv->local_attachment_store, uid, filename);
+				attach_file = e_cal_backend_create_cache_filename (E_CAL_BACKEND (cbex), uid, filename, i);
 				// Attach
 				attach_file_url = save_attach_file (attach_file, (gchar *) attach_data, byte_array->len);
 				g_free (attach_data);
@@ -1842,7 +1843,8 @@ receive_attachments (ECalBackendExchange *cbex,
 {
 	GSList *attach_urls = NULL;
 	GSList *l, *attach_list = NULL;
-	const gchar *uid = NULL;
+	const gchar *uid = NULL, *cache_dir;
+	gint fileindex;
 
 	g_return_val_if_fail (cbex != NULL, NULL);
 	g_return_val_if_fail (comp != NULL, NULL);
@@ -1853,8 +1855,9 @@ receive_attachments (ECalBackendExchange *cbex,
 	e_cal_component_get_uid (comp, &uid);
 	g_return_val_if_fail (uid != NULL, NULL);
 
+	cache_dir = e_cal_backend_get_cache_dir (E_CAL_BACKEND (cbex));
 	e_cal_component_get_attachment_list (comp, &attach_list);
-	for (l = attach_list; l; l = l->next) {
+	for (l = attach_list, fileindex = 0; l; l = l->next, fileindex++) {
 		const gchar *fname;
 		gchar *dest_url, *attach_file = NULL, *file_contents, *old_file = NULL;
 		gint len = 0;
@@ -1863,12 +1866,12 @@ receive_attachments (ECalBackendExchange *cbex,
 			attach_file = g_filename_from_uri ((gchar *) l->data, NULL, NULL);
 			fname = attach_file;
 
-			if (fname && cbex->priv->local_attachment_store && !g_str_has_prefix (fname, cbex->priv->local_attachment_store)) {
+			if (fname && cache_dir && !g_str_has_prefix (fname, cache_dir)) {
 				/* it's not in our store, thus save it there */
 				gchar *base_name = g_path_get_basename (attach_file);
 
 				old_file = attach_file;
-				attach_file = g_build_filename (cbex->priv->local_attachment_store, uid, base_name, NULL);
+				attach_file = e_cal_backend_create_cache_filename (E_CAL_BACKEND (cbex), uid, base_name, fileindex);
 				g_free (base_name);
 			}
 		} else {
@@ -1883,7 +1886,7 @@ receive_attachments (ECalBackendExchange *cbex,
 				 */
 				continue;
 			}
-			attach_file = g_strdup_printf ("%s/%s-%s", cbex->priv->local_attachment_store, uid, filename + 1);
+			attach_file = e_cal_backend_create_cache_filename (E_CAL_BACKEND (cbex), uid, filename + 1, fileindex);
 		}
 
 		/* attach_file should be g_freed */
@@ -1926,7 +1929,7 @@ build_msg (ECalBackendExchange *cbex,
 	gchar *from_name = NULL, *from_email = NULL;
 	GSList *attach_list = NULL, *l, *new_attach_list = NULL;
 	gchar *fname, *file_contents = NULL, *filename, *dest_url, *mime_filename, *attach_file;
-	gint len = 0;
+	gint len = 0, fileindex;
 
 	if (!g_ascii_strcasecmp (e_cal_backend_exchange_get_owner_email (E_CAL_BACKEND_SYNC (cbex)), exchange_account_get_email_id (cbex->account)))
 		e_cal_backend_exchange_get_from (E_CAL_BACKEND_SYNC (cbex), comp, &from_name, &from_email);
@@ -1949,7 +1952,7 @@ build_msg (ECalBackendExchange *cbex,
 
 	e_cal_component_get_uid (comp, &uid);
 	e_cal_component_get_attachment_list (comp, &attach_list);
-	for (l = attach_list; l; l = l->next) {
+	for (l = attach_list, fileindex = 0; l; l = l->next, fileindex++) {
 		gchar *mime_type;
 
 		if (!strncmp ((gchar *)l->data, "file://", 7)) {
@@ -1972,7 +1975,7 @@ build_msg (ECalBackendExchange *cbex,
 				continue;
 			}
 			mime_filename = g_strdup (filename + 1);
-			attach_file = g_strdup_printf ("%s/%s-%s", cbex->priv->local_attachment_store, uid, filename);
+			attach_file = e_cal_backend_create_cache_filename (E_CAL_BACKEND (cbex), uid, filename, fileindex);
 		}
 
 		/* mime_filename and attach_file should be g_freed */
@@ -2117,7 +2120,6 @@ finalize (GObject *object)
 		g_hash_table_destroy (cbex->priv->cache_unseen);
 	g_free (cbex->priv->object_cache_file);
 	g_free (cbex->priv->lastmod);
-	g_free (cbex->priv->local_attachment_store);
 
 	g_hash_table_destroy (cbex->priv->timezones);
 
@@ -2153,7 +2155,6 @@ e_cal_backend_exchange_class_init (ECalBackendExchangeClass *class)
 
 	backend_class = E_CAL_BACKEND_CLASS (class);
 	backend_class->start_view = start_view;
-	backend_class->set_online = set_online;
 	backend_class->internal_get_timezone = internal_get_timezone;
 
 	sync_class = E_CAL_BACKEND_SYNC_CLASS (class);
@@ -2190,5 +2191,9 @@ e_cal_backend_exchange_init (ECalBackendExchange *cbex)
 	cbex->priv->cache_unseen = NULL;
 
 	e_cal_backend_sync_set_lock (E_CAL_BACKEND_SYNC (cbex), TRUE);
+
+	g_signal_connect (
+		cbex, "notify::online",
+		G_CALLBACK (notify_online_cb), NULL);
 }
 
